<?PHP
/**
 * Pars-Nuke: Advanced Content Management System
 * Copyright 2012 Pars-Nuke Group, All Rights Reserved
 *
 * Website: http://parsnuke.com
 * License: http://www.gnu.org/licenses/
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * $Id: class_error.php 2012-01-28 18:01:16 (Iman92)$
 */

if (stristr(htmlentities($_SERVER['PHP_SELF']), "class_error.php")) {
	Header("Location: ../index.php");
	die();
}

if(!defined("E_STRICT"))
{
	// This constant has been defined since PHP 5.
	define("E_STRICT", 2048);
}

if(!defined("E_RECOVERABLE_ERROR"))
{
	// This constant has been defined since PHP 5.2.
	define("E_RECOVERABLE_ERROR", 4096);
}

if(!defined("E_DEPRECATED"))
{
	// This constant has been defined since PHP 5.3.
	define("E_DEPRECATED", 8192);
}

class debug {
	public $Events = array();
	public $StartTime;
	public $ErrorTypes = array(
		E_ERROR              => 'Error',
		E_WARNING            => 'Warning',
		E_PARSE              => 'Parsing Error',
		E_NOTICE             => 'Notice',
		E_CORE_ERROR         => 'Core Error',
		E_CORE_WARNING       => 'Core Warning',
		E_COMPILE_ERROR      => 'Compile Error',
		E_COMPILE_WARNING    => 'Compile Warning',
		E_DEPRECATED		 => 'Deprecated Warning',
		E_USER_ERROR         => 'User Error',
		E_USER_WARNING       => 'User Warning',
		E_USER_NOTICE        => 'User Notice',
		E_STRICT             => 'Runtime Notice',
		E_RECOVERABLE_ERROR  => 'Catchable Fatal Error',
	);

	public function __construct() {
		$this->StartTime = time();
		set_error_handler(array(&$this, 'ErrorHandler'));
	}

	public function ErrorHandler($errno, $errstr, $errfile, $errline) {
	    if ($errno == E_DEPRECATED || $errno == E_NOTICE || $errno == E_USER_NOTICE || $errno == E_STRICT) return;
	    $this->AddMessage($errno, $errstr, $errfile, $errline);
	    return true;
	}

	public function AddMessage($errno, $errstr, $errfile, $errline, $EventID = 0) {
		$errfile = str_replace('\\', '/', $errfile);
		$INCLUDE_PATH = str_replace('\\', '/', dirname(dirname(__FILE__)).'/');
		$errfile = str_replace($INCLUDE_PATH, '', $errfile);
		$this->Events[] = array('errno' => $errno, 'errstr' => $errstr, 'timestamp' => time(), 'errfile' => $errfile, 'errline' => $errline, 'eventid' => $EventID);
	}

	public function Output() {
	    if(!is_array($this->Events) || !count($this->Events)) return false;
		$EventHTML  = "<table cellpadding=\"3\" cellspacing=\"0\" style=\"width:100%;direction:ltr; background: #EEEEEE; border: #CCCCCC 1px solid;border-bottom:none\">\n";
		$EventHTML .= "  <tr>\n";
		$EventHTML .= "    <th style=\"width:130px;text-align:left;border-bottom:#CCCCCC 1px solid\">Error</th>\n";
		$EventHTML .= "    <th style=\"text-align:left;border-bottom:#CCCCCC 1px solid;border-left:#CCCCCC 1px solid\">Description</th>\n";
		$EventHTML .= "    <th style=\"width:300px;text-align:left;border-bottom:#CCCCCC 1px solid;border-left:#CCCCCC 1px solid\">File</th>\n";
		$EventHTML .= "    <th style=\"width:50px;text-align:left;border-bottom:#CCCCCC 1px solid;border-left:#CCCCCC 1px solid\">Line</th>\n";
		$EventHTML .= "  </tr>\n";
		$DivID = 0;

		foreach($this->Events as $Event) {
			$DivID++;
			if($DivID % 2 != 0) {
				$DivBG = '#F5F5F5';
			} else {
				$DivBG = '#EBEBEB';
			}
			if($Event['eventid'] == 1) $DivBG = '#FFCDCD';
			if($Event['eventid'] == 2) $DivBG = '#FFFFBF';
			$EventHTML .= "  <tr>\n";
			$EventHTML .= "    <td style=\"text-align:left;border-bottom:#CCCCCC 1px solid;background-color:{$DivBG}\">".$this->ErrorTypes[$Event['errno']]." (".$Event['errno'].")"."</td>\n";
			$EventHTML .= "    <td style=\"text-align:left;border-bottom:#CCCCCC 1px solid;border-left:#CCCCCC 1px solid;background-color:{$DivBG}\" title=\"".jdate('d-m-Y H:i:s', $Event['timestamp'])."\">".$Event['errstr']."</td>\n";
			$EventHTML .= "    <td style=\"text-align:left;border-bottom:#CCCCCC 1px solid;border-left:#CCCCCC 1px solid;background-color:{$DivBG}\">".$Event['errfile']."</td>\n";
			$EventHTML .= "    <td style=\"text-align:left;border-bottom:#CCCCCC 1px solid;border-left:#CCCCCC 1px solid;background-color:{$DivBG}\">".$Event['errline']."</td>\n";
			$EventHTML .= "  </tr>\n";
		}

		$EventHTML .= "</table>";
		return '<!--ParsNuke : ErrorHandler-->'.$EventHTML.'<!--ParsNuke : End ErrorHandler-->';
	}
}
?>